# Architecture Documentation

System architecture, design decisions, and technical deep dives for MCP Vector Search.

## Contents

- [Database Statistics Chunked Processing Optimization](./database-optimization.md) — Optimization for chunked processing of large database statistics
- [Reindexing Workflow Analysis](./indexing-workflow.md) — Deep dive into how the reindexing workflow operates
- [Connection Pooling Implementation](./performance.md) — Performance architecture using connection pooling

## Related Documentation

- [Parent Index](../README.md)
- [Development Documentation](../development/README.md)
- [Performance Documentation](../performance/README.md)
- [Research Notes](../research/README.md)
